#======================================
# AUTHORS
#======================================
AUTHORS="""\
#AUTHORS
%(author)s %(email)s
  initial development
"""
#======================================
# CHANGES
#======================================
CHANGES="""\
#CHANGES
See also doc/deshist (design history)

%(timestamp)s:
"""
#======================================
# INSTALL
#======================================
INSTALL="""\
#INSTALL

This is a standard distutils install, e.g.:

   mkdir workdir
   mv xyz-0.1.tar.gz workdir
   cd workdir
   gzip -cd xyz-0.1.tar.gz | tar xvf -
   cd xyz-0.1
   python setup.py build
   python setup.py install   (possibly as root)

"""
#======================================
# MANIFEST_IN
#======================================
MANIFEST_IN="""\
include AUTHORS CHANGES COPYING INSTALL MANIFEST.in README VERSION *.py
recursive-include %(projname)s *
recursive-include doc  go* *.py *.pdx *.help *.html 
recursive-include test *
global-exclude *~ *.pyc *.pyo
"""
#======================================
# README
#======================================
README="""\
#README
See doc/index.html
"""
#======================================
# SETUP
#=====================================
SETUP="""\
\"\"\"
NAME:
    setup.py
  
SYNOPSIS:
    python setup.py [options] [command]
    
DESCRIPTION:
    Using distutils "setup", build, install, or make tarball of the package.
    
OPTIONS:
    See Distutils documentation for details on options and commands.
    Common commands:
    build               build the package, in preparation for install
    install             install module(s)/package(s) [runs build if needed]
    install_data        install datafiles (e.g., in a share dir)   
    install_scripts     install executable scripts (e.g., in a bin dir)   
    sdist               make a source distribution
    bdist               make a binary distribution
    clean               remove build temporaries

EXAMPLES:
    cd mydir
    (cp myfile-0.1.tar.gz here)
    gzip -cd myfile-0.1.tar.gz | tar xvf -
    cd myfile-0.1
    python setup.py build
    python setup.py install
    python setup.py sdist
\"\"\"

#===imports=============
import os,sys,re,string,getopt,shutil,commands
from distutils.core import setup,Extension

try:
    from setuptools import find_packages
    can_find_packages=True
except:
    can_find_packages=False

#===globals======
modname='setup'
debug_p=0

#===configuration======
pkgname='%(projname)s'
version=string.strip(open("VERSION").readline())
exec_prefix=sys.exec_prefix
description = "%(projname)s"
author = "%(author)s"
author_email = "%(email)s"
url="%(url)s"
license = "%(license_name)s"

scripts=[]
py_modules=[]

if can_find_packages:
    packages=find_packages()
else:
    packages=[]
    
package_dir=[]
ext_modules=[]
#   [Extension('my_ext', ['my_ext.c', 'file1.c', 'file2.c'],
#           include_dirs=[''],
#           library_dirs=[''],
#           libraries=[''],)
#    ]

#===utilities==========================
def debug(ftn,txt):
    if debug_p:
        sys.stdout.write("%%s.%%s:%%s\\n" %% (modname,ftn,txt))
        sys.stdout.flush()

def fatal(ftn,txt):
    msg="%%s.%%s:FATAL:%%s\\n" %% (modname,ftn,txt)
    raise SystemExit, msg
    
def usage():
    print __doc__

#=============================
def main():
    setup (#---meta-data---
           name = pkgname,
           version = version,
           description = description,
           author = author,
           author_email = author_email,
           url=url,
           license = license,

           #---scripts,modules and packages---
           scripts=scripts,
           py_modules = py_modules,
           packages = packages,
           package_dir = package_dir,
           ext_modules = ext_modules,
           )
#==============================
if __name__ == '__main__':
    opts,pargs=getopt.getopt(sys.argv[1:],'hv',
                 ['help','version','exec-prefix'])
    for opt in opts:
        if opt[0]=='-h' or opt[0]=='--help':
            usage()
            sys.exit(0)
        elif opt[0]=='-v' or opt[0]=='--version':
            print modname+": version="+version
        elif opt[0]=='--exec-prefix':
            exec_prefix=opt[1]

    for arg in pargs:
        if arg=='test':
            do_test()
            sys.exit(0)
        elif arg=='doc':
            do_doc()
            sys.exit(0)
        else:
            pass

    main()
""" 
#======================================
# ALL_TESTS
#======================================
ALL_TESTS="""\
#!/usr/bin/env python
\"\"\"
NAME:
    all_tests.py  

SYNOPSIS:
    all_tests.py

DESCRIPTION:
    Run all unit tests

OPTIONS:
    -h,--help        this message
    -v,--version     version


EXAMPLES:
    1. As standalone
         all_tests.py

#Copyright (C) %(year)d  %(author)s %(email)s
#%(url)s
%(license_prefix)s

\"\"\"
#===imports======================
import sys,os,getopt,time,string
import unittest
sys.path.insert(0,"..")

#===globals======================
modname="all_tests"
__version__="0.1"

#--option args--
debug_p=1  #hardcoded to bypass unittest

#---positional args, default is empty---
pargs=[]    


#===utilities====================
def msg(txt):
    sys.stdout.write(txt)
    sys.stdout.flush()

def debug(ftn,txt):
    if debug_p:
        sys.stdout.write("%%s.%%s:%%s\\n" %% (modname,ftn,txt))
        sys.stdout.flush()

def fatal(ftn,txt):
    msg="%%s.%%s:FATAL:%%s\\n" %% (modname,ftn,txt)
    raise SystemExit, msg
 
def usage():
    print __doc__
#====================================
def suite():
    modules_to_test=('basic_tests',)
    alltests=unittest.TestSuite()
    for module in map(__import__, modules_to_test):
        alltests.addTest(module.suite())
    return alltests

#=============================
def main():
    unittest.main(defaultTest='suite')

#-------------------------
if __name__ == '__main__':
    ftn = "main"
    opts,pargs=getopt.getopt(sys.argv[1:],'hv',
                 ['help','version'])
    for opt in opts:
        if opt[0]=='-h' or opt[0]=='--help':
            print modname+": version="+__version__
            usage()
            sys.exit(0)
        elif opt[0]=='-v' or opt[0]=='--version':
            print modname+": version="+__version__
            sys.exit(0)

    #---make the object and run it---
    main()
"""
#======================================
# BASIC_TESTS
#======================================
BASIC_TESTS="""\
#!/usr/bin/env python
\"\"\"
NAME:
    basic_tests.py  

SYNOPSIS:
    basic_tests.py

DESCRIPTION:
    Run basic tests

OPTIONS:
    -h,--help        this message
    -v,--version     version

#Copyright (C) %(year)d  %(author)s %(email)s
#%(url)s
%(license_prefix)s
\"\"\"
#===imports======================
import sys,os,getopt,time,string,filecmp
from cStringIO import StringIO
import unittest
import %(projname)s.%(projname)s as model

#===globals======================
modname="basic_tests"
__version__="0.1"

#--option args--
debug_p=1  #hardcoded to bypass unittest

#---positional args, default is empty---
#---other----------------

#===utilities====================
def debug(ftn,txt):
    sys.stdout.write("%%s.%%s:%%s\\n" %% (modname,ftn,txt))
    sys.stdout.flush()

def fatal(ftn,txt):
    msg="%%s.%%s:FATAL:%%s\\n" %% (modname,ftn,txt)
    raise SystemExit, msg
 
def usage():
    print __doc__

#====================================
class BasicTestCase(unittest.TestCase):
    #------------------------
    def setUp(self):
        self.olddir=os.getcwd()
        self.obj=model.%(mainclass)s()
    #------------------------
    def tearDown(self):
        os.chdir(self.olddir)
        del self.obj
    #------------------------
    def mkfile(self,ftn,model):
        testname=  os.path.join('testdata','test_'  +ftn+'.txt')
        f=open(testname,'w')
        model.run(f)
        f.close()
        
    #------------------------
    def check(self,ftn):
        oraclename=os.path.join('testdata','oracle_'+ftn+'.txt')
        testname=  os.path.join('testdata','test_'  +ftn+'.txt')

        result=filecmp.cmp(oraclename,testname)
        self.assert_(result==1)
    #------------------------
    # Cases
    #------------------------
    def testHello(self):
        ftn='Hello'
        m=self.obj
        self.mkfile(ftn,m)

        self.check(ftn)
        


#=====================================
def suite():
    suite1 = unittest.TestSuite()
    cases=['Hello'
           ]
    
    for c in cases:
        suite1.addTest(BasicTestCase("test%%s" %% c))
    return suite1

#=============================
def main():
    unittest.main(defaultTest='suite')
    
#-------------------------
if __name__ == '__main__':
    ftn = "main"
    opts,pargs=getopt.getopt(sys.argv[1:],'hv',
                 ['help','version'])
    for opt in opts:
        if opt[0]=='-h' or opt[0]=='--help':
            print modname+": version="+__version__
            usage()
            sys.exit(0)
        elif opt[0]=='-v' or opt[0]=='--version':
            print modname+": version="+__version__
            sys.exit(0)

    #---make the object and run it---
    main()
"""
#======================================
# INDEX_PDX
#======================================
INDEX_PDX="""\
=include default_cfg.pdx
=cfg
title=%(projname)s Home page
toc_p=1
=end cfg
=include article_style.pdx

=head1 Basics

=list *
=item L<"%(projname)s.help","manpage">.
=item L<"AUTHORS","AUTHORS">
=item L<"CHANGES","CHANGES">
=item L<"INSTALL","INSTALL">
=item L<"README","README">
=end list

=head1 Documentation
=list *
=item L<"manual.html","User manual">
=item L<"devguide.html","Developer's Guide">
=item L<"deshist.html","Design History">
=end list

""" 



#============================
# MANUAL_PDX
#============================
MANUAL_PDX= """\
=include default_cfg.pdx
=cfg
title=%(projname)s User Manual
toc_p=1
=end cfg
=include article_style.pdx

=head1 Overview

=head1 Tutorial

=head1 Reference

""" 
#============================
# DEVGUIDE_PDX
#============================
DEVGUIDE_PDX= """\
=include default_cfg.pdx
=cfg
title=%(projname)s Developer's Guide
toc_p=1
=end cfg
=include article_style.pdx

=head1 Overview

=head1 Architecture

=head1 Edit Cycle

""" 

#============================
# DESHIST_PDX
#============================
DESHIST_PDX="""\
=include default_cfg.pdx
=cfg
title=%(projname)s Design History
toc_p=1
=end cfg
=include article_style.pdx

=head1 %(timestamp)s
"""




































